@@ -53,14 +53,13 @@ enum {
 
 typedef struct {
 	char *name;
+	char *cname;
 	char *comment;
 	GdkPixbuf *pixbuf;
 	char *bugzilla;
 	char *product;
 	char *component;
 	char *version;
-	char *email;
-	GtkTreeIter iter;
 } BugzillaApplication;
 
 struct _GnomeVersionInfo {
@@ -75,9 +74,12 @@ typedef struct _GnomeVersionInfo GnomeVersionInfo;
 GHashTable*        load_applications       (void);
 int                bugzilla_parse_response (SoupMessage *msg,
                                             GError **err);
+gboolean	   bugzilla_search_for_package (gpointer key, gpointer value, const char *package);
+
 SoupXmlrpcMessage* bugzilla_create_report  (BugzillaApplication *app, 
                                             GnomeVersionInfo *gnome_version,
                                             const char *username,
+                                            const char *title,
                                             const char *text,
                                             GladeXML *xml,
                                             GError **err);
