@@ -50,6 +50,9 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 	gnome_vfs_init ();
 	
+	if (!bonobo_activation_is_initialized()) {
+		bonobo_activation_init (argc, argv);
+	}
 
 	apps = load_applications ();
 	
